"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveMinify = exports.resolveBuiltinsOptions = void 0;
const browserslist_1 = require("browserslist");
function resolveDefine(define) {
    // @ts-expect-error
    const entries = Object.entries(define).map(([key, value]) => [
        key,
        value === undefined ? "undefined" : value
    ]);
    return Object.fromEntries(entries);
}
function resolveHtml(html) {
    // @ts-expect-error
    return html.map(c => {
        for (const key in c.meta) {
            const value = c.meta[key];
            if (typeof value === "string") {
                c.meta[key] = {
                    name: key,
                    content: value
                };
            }
        }
        return c;
    });
}
function resolveDecorator(decorator) {
    if (decorator === false) {
        return undefined;
    }
    if (decorator === undefined || decorator === true) {
        decorator = {};
    }
    return Object.assign({
        legacy: true,
        emitMetadata: true
    }, decorator);
}
function resolveEmotion(emotion, isProduction) {
    var _a, _b, _c;
    if (!emotion) {
        return undefined;
    }
    if (emotion === true) {
        emotion = {};
    }
    const autoLabel = (_a = emotion === null || emotion === void 0 ? void 0 : emotion.autoLabel) !== null && _a !== void 0 ? _a : "dev-only";
    const emotionConfig = {
        enabled: true,
        // @ts-expect-error autoLabel is string for JavaScript interface, however is boolean for Rust interface
        autoLabel: autoLabel === "dev-only" ? !isProduction : autoLabel === "always",
        importMap: emotion === null || emotion === void 0 ? void 0 : emotion.importMap,
        labelFormat: (_b = emotion === null || emotion === void 0 ? void 0 : emotion.labelFormat) !== null && _b !== void 0 ? _b : "[local]",
        sourcemap: isProduction ? false : (_c = emotion === null || emotion === void 0 ? void 0 : emotion.sourceMap) !== null && _c !== void 0 ? _c : true
    };
    return JSON.stringify(emotionConfig);
}
function resolveBuiltinsOptions(builtins, { contextPath, isProduction }) {
    const browserslist = (0, browserslist_1.loadConfig)({ path: contextPath }) || [];
    return {
        ...builtins,
        define: resolveDefine(builtins.define || {}),
        html: resolveHtml(builtins.html || []),
        browserslist,
        decorator: resolveDecorator(builtins.decorator),
        minify: resolveMinify(builtins, isProduction),
        emotion: resolveEmotion(builtins.emotion, isProduction)
    };
}
exports.resolveBuiltinsOptions = resolveBuiltinsOptions;
function resolveMinify(builtins, isProduction) {
    if (builtins.minify) {
        if (builtins.minify === true) {
            return {
                enable: true,
                passes: 1
            };
        }
        else {
            return {
                ...builtins.minify,
                enable: true
            };
        }
    }
    else if (builtins.minify === false) {
        return {
            enable: false,
            passes: 1
        };
    }
    else {
        return {
            enable: isProduction,
            passes: 1
        };
    }
}
exports.resolveMinify = resolveMinify;
//# sourceMappingURL=builtins.js.map